@@ -66,7 +66,7 @@ sub probe_envvars {
 # deprecated INCLUDES/LIBS into %ENV
 sub probe_pkgconfig {
     my $pkg_config = $ENV{ PKGCONFIG_CMD } || 'pkg-config';
-    foreach my $pkg ( qw(libzmq zeromq2) ) {
+    foreach my $pkg ( qw(libzmq zeromq3) ) {
         print "Probing $pkg via $pkg_config ...\n";
         my $version = qx/$pkg_config --modversion $pkg/;
         chomp $version;
@@ -77,11 +77,6 @@ sub probe_pkgconfig {
 
         print " + found $pkg $version\n";
 
-        my ($major, $minor, $micro) = split /\./, $version;
-        if ( $major != 2 && $minor != 1 ) {
-            die "Whoa there! We don't support anything other than libzmq 2.1.x";
-        }
-
         if (! $ENV{ZMQ_INCLUDES}) {
             if (my $cflags = qx/$pkg_config --cflags-only-I $pkg/) {
                 chomp $cflags;
@@ -111,4 +106,4 @@ sub probe_pkgconfig {
 
         last;
     }
-}
\ No newline at end of file
+}
